@@ -52,8 +52,8 @@ define('M3_TITLE_BRACKET_END',		'」');					// タイトルを括弧表記する
 // ########## システム関係 ##########
 // システム基本情報
 define('M3_SYSTEM_NAME',			'Magic3');		// システム名称
-define('M3_SYSTEM_VERSION',			'2.13.2');		// システムのバージョン
-define('M3_SYSTEM_RELEASE_DATE',	'2015/7/9');	// システムのリリース日付
+define('M3_SYSTEM_VERSION',			'2.13.3');		// システムのバージョン
+define('M3_SYSTEM_RELEASE_DATE',	'2015/7/17');	// システムのリリース日付
 define('M3_SYSTEM_ID',				'M3');			// コンポーネント識別用ID
 define('M3_SYSTEM_DESCRIPTION',		'Magic3 is open source cms and web communication platform.');		// システムの説明
 define('M3_SYSTEM_MIN_MEMORY',		'16M');			// 最小メモリ使用量
@@ -111,6 +111,7 @@ define('M3_TAG_MACRO_AVATAR',		'AVATAR');								// アバター置換キー
 define('M3_TAG_MACRO_URL',			'URL');									// URL置換キー
 define('M3_TAG_MACRO_ACCOUNT',		'ACCOUNT');								// アカウント置換キー
 define('M3_TAG_MACRO_PASSWORD',		'PASSWORD');							// パスワード置換キー
+define('M3_TAG_MACRO_UPDATES',		'UPDATES');								// 更新情報置換キー
 define('M3_TAG_MACRO_FILES',		'FILES');								// 添付ファイル置換キー
 define('M3_TAG_MACRO_PAGES',		'PAGES');								// ページリンク置換キー
 define('M3_TAG_MACRO_LINKS',		'LINKS');								// 関連リンク置換キー
@@ -122,6 +123,7 @@ define('M3_TAG_MACRO_PERMALINK',	'PERMALINK');							// パーマリンク置換
 define('M3_TAG_MACRO_RATE',			'RATE');								// 評価機能置換キー
 define('M3_TAG_MACRO_BUTTON',		'BUTTON');								// ボタン置換キー
 define('M3_TAG_MACRO_WIDGET',		'WIDGET');								// ウィジェット埋め込みキー
+define('M3_TAG_MACRO_TOOLBAR',		'TOOLBAR');								// ツールバー置換キー
 define('M3_TAG_MACRO_OPTIONAL',		'OPTIONAL');							// 任意オプション置換キー
 define('M3_TAG_MACRO_SITE_NAME',		'SITE_NAME');						// サイト情報置換キー(サイト名)
 define('M3_TAG_MACRO_SITE_URL',			'SITE_URL');						// サイト情報置換キー(URL)
@@ -209,6 +211,7 @@ define('M3_COOKIE_LANG',				'LANG');			// 言語
 define('M3_COOKIE_CART_ID',				'CARTID');			// EコマースカートID
 define('M3_COOKIE_DISP_ID',				'DISPID');			// クライアント画面設定ID
 define('M3_COOKIE_AUTO_LOGIN',			'LOGIN');			// 自動ログインID
+define('M3_COOKIE_ADMIN_WIDGET_TOOL',	'M3WIDGETTOOL');			// (管理機能用)ウィジェットツール状態
 
 // 表示データフォーマット
 define('M3_VIEW_FORMAT_DATETIME',		'Y/m/d H:i:s');		// 日時
