@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 1430 2009-01-11 06:32:02Z fishbone $
+ * @version    SVN: $Id: index.php 1797 2009-04-24 09:36:38Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -20,8 +20,6 @@ defined('M3_SYSTEM') or die('Access error: Direct access denied.');
 global $HELP;
 
 // ########## トップアクセスコンテンツ一覧 ##########
-$HELP['title']['title'] = 'タイトル';
-$HELP['title']['body'] = '一覧のタイトル名です。';
 $HELP['view_count']['title'] = '表示項目数';
 $HELP['view_count']['body'] = 'リストの最大表示項目数を設定します。';
 ?>
