@@ -28,8 +28,8 @@ global $interwiki;
 global $menubar;
 
 global $nofollow;
-global $trackback;
-global $referer;
+//global $trackback;
+//global $referer;
 global $nowikiname;
 global $autolink;
 global $function_freeze;
@@ -221,11 +221,11 @@ $nofollow = 0; // 1 = Try hiding from search engines
 // TrackBack feature
 
 // Enable Trackback
-$trackback = 0;
+//$trackback = 0;
 
 /////////////////////////////////////////////////
 // Referer list feature
-$referer = 0;
+//$referer = 0;
 //$referer = 1;			// tmp for magic3
 
 /////////////////////////////////////////////////
