@@ -38,7 +38,7 @@ global $_msg_symbol;
 global $_msg_other;
 global $_msg_help;
 global $_msg_week;
-global $_msg_content_back_to_top;
+//global $_msg_content_back_to_top;
 global $_msg_word;
 global $_msg_no_operation_allowed;
 global $_msg_password;
@@ -206,7 +206,7 @@ $_msg_symbol      = 'Symbols';
 $_msg_other       = 'Others';
 $_msg_help        = 'View Text Formatting Rules';
 $_msg_week        = array('Sun','Mon','Tue','Wed','Thu','Fri','Sat');
-$_msg_content_back_to_top = '<div class="jumpmenu"><a href="#wiki_top">&uarr;</a></div>';
+//$_msg_content_back_to_top = '<div class="jumpmenu"><a href="#wiki_top">&uarr;</a></div>';
 $_msg_word        = 'These search terms have been highlighted:';
 $_title_no_operation_allowed = 'No Operation Allowed';
 $_msg_no_operation_allowed = 'This operation is not allowed.';
