@@ -39,7 +39,7 @@ global $_msg_symbol;
 global $_msg_other;
 global $_msg_help;
 global $_msg_week;
-global $_msg_content_back_to_top;
+//global $_msg_content_back_to_top;
 global $_msg_word;
 global $_msg_no_operation_allowed;
 global $_msg_password;
@@ -208,7 +208,7 @@ $_msg_symbol         = '記号';
 $_msg_other          = '日本語';
 $_msg_help           = 'テキスト整形のルールを表示する';
 $_msg_week           = array('日','月','火','水','木','金','土');
-$_msg_content_back_to_top = '<div class="jumpmenu"><a href="#wiki_top">&uarr;</a></div>';
+//$_msg_content_back_to_top = '<div class="jumpmenu"><a href="#wiki_top">&uarr;</a></div>';
 $_msg_word           = 'これらのキーワードがハイライトされています：';
 $_title_no_operation_allowed = '実行不可';
 $_msg_no_operation_allowed = 'この操作は実行できません';
