@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2014 Magic3 Project.
+ * @copyright  Copyright 2006-2015 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -25,7 +25,12 @@ function plugin_template_action()
 	global $_err_template_already, $_err_template_invalid, $_msg_template_force;
 	global $gEnvManager;
 	
-	if (PKWK_READONLY) die_message('PKWK_READONLY prohibits editing');
+//	if (PKWK_READONLY) die_message('PKWK_READONLY prohibits editing');
+
+	// ### パスワード認証フォーム表示 ###
+	// 認証されている場合はスルーして関数以降を実行
+	$retStatus = password_form();
+	if (!empty($retStatus)) return $retStatus;
 	
 	// テンプレートタイプに合わせて出力を変更
 	$templateType = $gEnvManager->getCurrentTemplateType();
@@ -49,11 +54,11 @@ function plugin_template_action()
 
 	// edit
 	if ($is_pagename = is_pagename($page) && (!$is_page || WikiParam::getVar('force') != '')){
-		$postdata       = join('', array_splice($lines, $begin, $end - $begin + 1));
-		$retvar['msg']  = $_title_edit;
-		$retvar['body'] = edit_form($page, $postdata);
+		$postdata	= join('', array_splice($lines, $begin, $end - $begin + 1));
+		$msg		= $_title_edit;
+		$body		= edit_form($page, $postdata);
 		WikiParam::setRefer($page);
-		return $retvar;
+		array('msg' => $msg, 'body' => $body);
 	}
 	$begin_select = $end_select = '';
 	for ($i = 0; $i < count($lines); $i++) {
@@ -67,7 +72,7 @@ function plugin_template_action()
 	}
 
 	$_page = htmlspecialchars($page);
-	$msg = $tag = '';
+	$msg = $body = $tag = '';
 	if ($is_page) {
 		$msg = $_err_template_already;
 		
@@ -87,34 +92,29 @@ function plugin_template_action()
 	
 	// テンプレートタイプに合わせて出力を変更
 	if ($templateType == M3_TEMPLATE_BOOTSTRAP_30){		// Bootstrap型テンプレートの場合
-		$ret     = <<<EOD
-<form action="$postScript" method="post" class="form" role="form">
-  <input type="hidden" name="plugin" value="template" />
-  <input type="hidden" name="refer"  value="$s_refer" />
-  <div class="form-group"><label for="_p_template_begin">$_msg_template_start</label><select class="form-control" name="begin" id="_p_template_begin" size="10">$begin_select</select></div>
-  <div class="form-group"><label for="_p_template_end">$_msg_template_end</label><select class="form-control" name="end" id="_p_template_end" size="10">$end_select</select></div>
-  <div class="form-group"><label for="_p_template_refer">$_msg_template_refer <input type="text" class="form-control" name="page" id="_p_template_refer" value="$s_page" size="15" /></label></div>
-  <input type="submit" name="submit" class="button btn" value="$_btn_template_create" /> $tag
-</form>
-EOD;
+		$body .= '<form action="' . $postScript . '" method="post" class="form" role="form">' . M3_NL;
+		$body .= '<input type="hidden" name="plugin" value="template" />' . M3_NL;
+		$body .= '<input type="hidden" name="refer"  value="' . $s_refer . '" />' . M3_NL;
+		$body .= '<div class="form-group"><label for="_p_template_begin">' . $_msg_template_start . '</label><select class="form-control" name="begin" id="_p_template_begin" size="10">' . $begin_select . '</select></div>' . M3_NL;
+		$body .= '<div class="form-group"><label for="_p_template_end">' . $_msg_template_end . '</label><select class="form-control" name="end" id="_p_template_end" size="10">' . $end_select . '</select></div>' . M3_NL;
+		$body .= '<div class="form-group"><label for="_p_template_refer">' . $_msg_template_refer . ' <input type="text" class="form-control" name="page" id="_p_template_refer" value="' . $s_page . '" size="15" /></label></div>' . M3_NL;
+		$body .= '<input type="submit" name="submit" class="button btn" value="' . $_btn_template_create . '" /> ' . $tag . M3_NL;
+		$body .= '</form>' . M3_NL;
 	} else {
-		$ret     = <<<EOD
-<form action="$postScript" method="post" class="form">
- <div>
-  <input type="hidden" name="plugin" value="template" />
-  <input type="hidden" name="refer"  value="$s_refer" />
-  $_msg_template_start <select name="begin" size="10">$begin_select</select><br /><br />
-  $_msg_template_end   <select name="end"   size="10">$end_select</select><br /><br />
-  <label for="_p_template_refer">$_msg_template_refer</label>
-  <input type="text" name="page" id="_p_template_refer" value="$s_page" />
-  <input type="submit" name="submit" class="button" value="$_btn_template_create" /> $tag
- </div>
-</form>
-EOD;
+		$body .= '<form action="' . $postScript . '" method="post" class="form">' . M3_NL;
+		$body .= '<div>' . M3_NL;
+		$body .= '<input type="hidden" name="plugin" value="template" />' . M3_NL;
+		$body .= '<input type="hidden" name="refer"  value="' . $s_refer . '" />' . M3_NL;
+		$body .= $_msg_template_start . ' <select name="begin" size="10">' . $begin_select . '</select><br /><br />' . M3_NL;
+		$body .= $_msg_template_end . ' <select name="end"   size="10">' . $end_select . '</select><br /><br />' . M3_NL;
+		$body .= '<label for="_p_template_refer">' . $_msg_template_refer . '</label>' . M3_NL;
+		$body .= '<input type="text" name="page" id="_p_template_refer" value="' . $s_page . '" />' . M3_NL;
+		$body .= '<input type="submit" name="submit" class="button" value="' . $_btn_template_create . '" /> ' . $tag . M3_NL;
+		$body .= '</div>' . M3_NL;
+		$body .= '</form>' . M3_NL;
 	}
 	
-	$retvar['msg']  = ($msg == '') ? $_title_template : $msg;
-	$retvar['body'] = $ret;
-	return $retvar;
+	$msg = ($msg == '') ? $_title_template : $msg;
+	return array('msg' => $msg, 'body' => $body);
 }
 ?>
